==> GO_1.16.0.tar.gz: GO/man/GOMFOFFSPRING.Rd <==
\name{GOMFOFFSPRING}
\alias{GOMFOFFSPRING}
\title{Annotation of GO Identifiers to their Molecular Function Offspring} 
\description{
  This data set describes associations between GO molecular function (MF)
  terms and their offspring MF terms, based on the directed acyclic
  graph (DAG) defined by the Gene Ontology Consortium. The format is an R
  environment mapping the GO MF terms to all offspring terms, where an
  ancestor term is a more specific GO term that is preceded
  by the given GO term in the DAG (in other words, the children and all
  their children, etc.).
}
\details{
  Each GO MF term is mapped to a vector of offspring GO MF terms.

  Molecular function is defined as the tasks performed by individual
  gene products; examples are transcription factor and DNA helicase as
  defined by Gene Ontology Consortium.  
  
  Mappings were based on data provided by:

  Gene Ontology:\\url{http://gopher5/compbio/annotationSourceData/archive.godatabase.org/latest/}. Built: 08-Feb-2007

  Package built: Fri Mar  2 13:37:12 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOMFOFFSPRING)
  # Remove GO identifiers that do not have any offspring
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
    # Get the offspring GO identifiers for the first two elents of xx
  goids <- xx[1:2]
  }
}
\keyword{datasets}

==> GO_2.0.1.tar.gz: GO/man/GOMFOFFSPRING.Rd <==
\name{GOMFOFFSPRING}
\alias{GOMFOFFSPRING}
\title{Annotation of GO Identifiers to their Molecular Function Offspring} 
\description{
  This data set describes associations between GO molecular function (MF)
  terms and their offspring MF terms, based on the directed acyclic
  graph (DAG) defined by the Gene Ontology Consortium. The format is an R
  environment mapping the GO MF terms to all offspring terms, where an
  ancestor term is a more specific GO term that is preceded
  by the given GO term in the DAG (in other words, the children and all
  their children, etc.).
}
\details{
  Each GO MF term is mapped to a vector of offspring GO MF terms.

  Molecular function is defined as the tasks performed by individual
  gene products; examples are transcription factor and DNA helicase as
  defined by Gene Ontology Consortium.  
  
  Mappings were based on data provided by:

  Gene Ontology:\\url{ftp://ftp.geneontology.org/pub/go/godatabase/archive/latest}. Built: Build Information not available

  Package built: Wed Aug 29 09:09:17 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOMFOFFSPRING)
  # Remove GO identifiers that do not have any offspring
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
    # Get the offspring GO identifiers for the first two elents of xx
  goids <- xx[1:2]
  }
}
\keyword{datasets}
